@@ -111,6 +111,9 @@ class UsersAndGroup(object):
             user["unix_user"] = False
         for key in u:
             if key not in self._IGNORE_KEYS:
+                if key =='sAMAccountName':
+                    user['name'] = u['sAMAccountName']
+                    user['sAMAccountName'] = u['sAMAccountName']
                 if key in self._UNIX_KEYS:
                     if unix:
                         user["unix_user"][key] = u[key]
